@@ -29,5 +29,5 @@ class Enzyme(object):
             if unique:
                 peptides += list(collections.OrderedDict.fromkeys([i for i in digests if len(i) >= min and len(i) <= max]))
             else:
-                peptides = [i for i in digests if len(i) >= min and len(i) <= max]
+                peptides += [i for i in digests if len(i) >= min and len(i) <= max]
         return peptides
\ No newline at end of file
