@@ -109,7 +109,7 @@ class XMLFileNameMixin(object):
             filetag = filenode[1]
             file_params = dict([(i.get('name'), i.get('value')) for i in filetag.findall('{0}cvParam'.format('{http://psi.hupo.org/ms/mzml}'))])
             for identifier, filetype in identifiers:
-                if filter(lambda x: identifier in x.lower(), file_params.keys()):
+                if any(filter(lambda x: identifier in x.lower(), file_params.keys())):
                     self.filetype = filetype
                     break
             filetag.clear()
@@ -1483,7 +1483,7 @@ class ThermoMSFIterator(templates.GenericIterator, GenericProteomicIterator):
         """
         get a random scan
         """
-        sql = "select sp.Spectrum, p.Sequence, p.PeptideID, p.SpectrumID from spectrumheaders sh left join spectra sp on (sp.UniqueSpectrumID=sh.UniqueSpectrumID) left join peptides p on (sh.SpectrumID=p.SpectrumID) where sh.SpectrumID = %d and p.Sequence = '%s'"%(int(specId),peptide)
+        sql = self.base_sql + " where sh.SpectrumID = %d and p.Sequence = '%s'"%(int(specId),peptide)
         self.cur.execute(sql)
         i = self.cur.fetchone()
         if not i:
@@ -1951,4 +1951,4 @@ class MQIterator(templates.GenericIterator, GenericProteomicIterator):
         sql = "select sp.Spectrum, p.Sequence, p.PeptideID from spectrumheaders sh left join spectra sp on (sp.UniqueSpectrumID=sh.UniqueSpectrumID) left join peptides p on (sh.SpectrumID=p.SpectrumID) where p.Sequence = '%s'"%(peptide)
         self.cur.execute(sql)
         for i in self.cur.fetchall():
-            yield self.parseFullScan(i)
\ No newline at end of file
+            yield self.parseFullScan(i)
