@@ -3,6 +3,9 @@ import argparse
 import sys
 from distutils import spawn
 from collections import deque
+
+from six import string_types
+
 import pythomics.proteomics.config as protein_config
 
 
@@ -14,10 +17,10 @@ class GenericIterator(object):
 
     def __init__(self, filename, delimiter='\n', *args, **kwargs):
         self.delimiter = delimiter
-        if isinstance(filename, basestring) and filename.endswith('.gz'):
+        if isinstance(filename, string_types) and filename.endswith('.gz'):
             self.gzip = True
             self.filename = gzip.GzipFile(filename)
-        elif isinstance(filename, basestring):
+        elif isinstance(filename, string_types):
             self.filename = open(filename)
         elif isinstance(filename, (file,)):
             if filename.name.endswith('.gz'):
@@ -56,6 +59,9 @@ class GenericIterator(object):
         else:
             return self.filename.next().strip()
 
+    def __next__(self):
+        return self.next()
+
 
 class CustomParser(argparse.ArgumentParser):
     def __init__(self, *args, **kwrds):
@@ -69,7 +75,7 @@ class CustomParser(argparse.ArgumentParser):
         self.add_argument('--min', help="Minimum cleavage length", type=int, default=7)
         self.add_argument('--max', help="Maximum cleavage length", type=int, default=30)
 
-    def add_delimited_file(self, files=None, delimiter=None, cols=None, header=None, help="The delimited file."):
+    def add_delimited_file(self, files=None, delimiter=None, cols=None, col_default=1, header=None, help="The delimited file."):
         if files is None:
             files = ['-t', '--tsv']
         if delimiter is None:
@@ -80,7 +86,7 @@ class CustomParser(argparse.ArgumentParser):
             header = ['--header']
         self.add_argument(*files, help=help, type=argparse.FileType('r'), required=True)
         self.add_argument(*delimiter, help="The delimiter for fields.", type=str, default='\t')
-        self.add_argument(*cols, help="The column of interest (default: 1). Can be a column name.", type=str, default=1)
+        self.add_argument(*cols, help="The column of interest (default: 1). Can be a column name.", type=str, default=col_default)
         self.add_argument(*header, help="The number of headers lines (default: 1).", type=int, default=1)
 
     def add_fasta(self, help="The fasta file to operate on."):
